==> huaweicloudsdkga-3.1.98-py2.py3-none-any.whl: huaweicloudsdkga/v1/model/update_ip_group_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateIpGroupRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'ip_group': 'UpdateIpGroupOption'
    }

    attribute_map = {
        'ip_group': 'ip_group'
    }

    def __init__(self, ip_group=None):
        """UpdateIpGroupRequestBody

        The model defined in huaweicloud sdk

        :param ip_group: 
        :type ip_group: :class:`huaweicloudsdkga.v1.UpdateIpGroupOption`
        """
        
        

        self._ip_group = None
        self.discriminator = None

        self.ip_group = ip_group

    @property
    def ip_group(self):
        """Gets the ip_group of this UpdateIpGroupRequestBody.

        :return: The ip_group of this UpdateIpGroupRequestBody.
        :rtype: :class:`huaweicloudsdkga.v1.UpdateIpGroupOption`
        """
        return self._ip_group

    @ip_group.setter
    def ip_group(self, ip_group):
        """Sets the ip_group of this UpdateIpGroupRequestBody.

        :param ip_group: The ip_group of this UpdateIpGroupRequestBody.
        :type ip_group: :class:`huaweicloudsdkga.v1.UpdateIpGroupOption`
        """
        self._ip_group = ip_group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateIpGroupRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkga-3.1.149-py2.py3-none-any.whl: huaweicloudsdkga/v1/model/update_ip_group_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateIpGroupRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'ip_group': 'UpdateIpGroupOption'
    }

    attribute_map = {
        'ip_group': 'ip_group'
    }

    def __init__(self, ip_group=None):
        r"""UpdateIpGroupRequestBody

        The model defined in huaweicloud sdk

        :param ip_group: 
        :type ip_group: :class:`huaweicloudsdkga.v1.UpdateIpGroupOption`
        """
        
        

        self._ip_group = None
        self.discriminator = None

        self.ip_group = ip_group

    @property
    def ip_group(self):
        r"""Gets the ip_group of this UpdateIpGroupRequestBody.

        :return: The ip_group of this UpdateIpGroupRequestBody.
        :rtype: :class:`huaweicloudsdkga.v1.UpdateIpGroupOption`
        """
        return self._ip_group

    @ip_group.setter
    def ip_group(self, ip_group):
        r"""Sets the ip_group of this UpdateIpGroupRequestBody.

        :param ip_group: The ip_group of this UpdateIpGroupRequestBody.
        :type ip_group: :class:`huaweicloudsdkga.v1.UpdateIpGroupOption`
        """
        self._ip_group = ip_group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateIpGroupRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
